#
#
#	Loren Williams
#	Georgia Tech
#	Protein Folds
# 
#----------------------------------------------------------------
	## General Header Commands ##

# delete all objects and reset pymol
reinitialize

# set the background color to white
bg_color white

# make the background transparent for #ray trace 
set ray_opaque_background, 0

# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2

# turn off shadows
set ray_shadows, 0

# set the mouse mode for laptop.
config_mouse one_button

# run the python program for hydrogen bonding interactions.
run files/python/list_hbonds.py
#------ put the python program list_hbonds.py
#------into the directory python.


#-----------alpha helical proteins----------------------
load files/banner.pdb, ---alpha-----------------


load files/hemerythrin_alpha.pdb, hemerythrin_alpha
remove hemerythrin and not chain A
load files/3e5o_co.pdb, myoglobin_alpha
load files/Gfh1_alpha.pdb, Gfh1_alpha
remove Gfh1_alpha and chain B
remove Gfh1_alpha and not resi 7-72
load files/colicin_alpha.pdb, colicin_alpha
load files/hemoglobin_alpha.pdb, hemoglobin_alpha
remove hemoglobin_alpha and chain B
load files/hemoglobin_dodecamer_alpha.pdb, hemoglobin_dodecamer_alpha
load files/saposin_alpha.pdb, saposin_alpha
remove chain C and saposin_alpha
#load files/polycystein_beta.pdb, polycystein_beta


align myoglobin_alpha, hemerythrin_alpha
align Gfh1_alpha, hemerythrin_alpha
align colicin_alpha, hemerythrin_alpha
align hemoglobin_alpha, hemerythrin_alpha
align hemoglobin_dodecamer_alpha, hemerythrin_alpha
align saposin_alpha, hemerythrin_alpha

#a------------alpha + beta proteins----------------------
load files/banner.pdb, ---alpha + beta--------------

load files/1ZNI.pdb, insulin
load files/1K6U.pdb, BPTI
load files/1eue.pdb, c_chrome_b5
remove c_chrome_b5 and chain B
load files/1kf4.pdb, r_nuclease
load files/1dpx.pdb, h_lysozyme

align insulin, hemerythrin_alpha
align BPTI, hemerythrin_alpha
align c_chrome_b5, hemerythrin_alpha
align r_nuclease, hemerythrin_alpha
align h_lysozyme, hemerythrin_alpha

# Alpha+beta:
#- Insulin (INS)
#- pancreatic trypsin inhibitor (PTI)
#- cytochrome_b5 (CB5)
#- ribonuclease (RNS)
#- hen lysozyme (LZM)
#- staphyloccocal nuclease (SNS)
#- T4 lysozyme (LZ4)
#- papain (PAP)
#- thermolysis (TLS)


#-------------beta sheet proteins----------------------
load files/banner.pdb, ----beta---------------

load files/1brf.pdb, rubredoxin
load files/1mim.pdb, imm_const_region
load files/5o3y.pdb, SOD1
remove chain F and SOD1
load files/carboxylase_beta.pdb, carboxylase
load files/dehydrogenase_beta.pdb, dehydrogenase
remove dehydrogenase and chain C+D
load files/secretion_beta.pdb, secretion


align rubredoxin, hemerythrin_alpha
align imm_const_region, hemerythrin_alpha
align SOD1, hemerythrin_alpha
align carboxylase, hemerythrin_alpha
align dehydrogenase, hemerythrin_alpha
align secretion, hemerythrin_alpha

All-beta:
#- rubredoxin (RUB)
#- immunoglobulin constant region (IGC)
#- immunoglobulin variable region (IGV)
#- prealbumin (PBN)
#- superoxide dismutase (SDM)
#- concanavalin A (CON)
#- chymotrypsin (CHT)


#a------------alpha/beta proteins----------------------
load files/banner.pdb, ----alpha/beta---------------

load files/5dqy.pdb, thioredoxin
load files/1fue.pdb, flavodoxin
load files/amidase_alpha_beta.pdb, amidase
load files/rkip_alph_beta.pdb, rkip
load files/P35_alpha_beta.pdb, P35
remove P35 and chain A+B
load files/TIM_alpha_beta.pdb, TIM
remove chain 1 and TIM_alpha_beta
load files/ribonuclease_inhibitor_alpha_beta.pdb, ribonuclease_inhibitor_alpha_beta
remove ribonuclease_inhibitor_alpha_beta and chain E

#a------------superimpose----------------------

align thioredoxin, hemerythrin_alpha
align flavodoxin, hemerythrin_alpha
align amidase, hemerythrin_alpha
align rkip, hemerythrin_alpha
align P35, hemerythrin_alpha
align TIM, hemerythrin_alpha
align TIM_alpha_beta, hemerythrin_alpha
align ribonuclease_inhibitor_alpha_beta, hemerythrin_alpha


#Alpha/beta:
#- thioredoxin (TRX)
#- flavodoxin (FLN)
#- alcohol dehydrogenase coenzyme domain (ADH)
#- adenyl kinase (AKN)
#- phosphoglycerate mutase (PGM)
#- triose phosphate isomerase (TIM)
#- subtilisin (SUB)
#- carboxypeptidase (CPA)
#- lactate dehydrogenase (LDH)
#- phosphoglycerate kinase (PGK)
#- D-glyceraldehyde-3-phosphate dehydrogenase (GPD)
#- hexokinase (HKN)

#a------------SET UP

hide everything, *
show cartoon, *
set cartoon_smooth_loops,0


color red, ss h
color yellow, ss s
color green, ss l+''

#color red, all
#select hydrophobes,(resn ala+gly+val+ile+leu+phe+met)
#show sticks, (hydrophobes and (!name c+n+o))
#color blue, hydrophobes

#disable hydrophobes
#show spheres, resn hem
#color cyan, resn hem

remove resn hoh
disable all
enable hemerythrin_alpha

#enable banner
#label banner, "Red is Hydrophilic, Blue is Hydrophobic"
#show label, banner


set_view (\
     0.927350402,   -0.097074844,   -0.361382008,\
    -0.094083741,    0.874250114,   -0.476270974,\
     0.362172604,    0.475669980,    0.801603496,\
     0.000000000,    0.000000000, -129.698745728,\
    13.816665649,   50.578388214,   43.836227417,\
   102.255477905,  157.142013550,  -20.000000000 )
### cut above here and paste into script ### 